(defproject 1-gb-api "2.0.0"
  :description "API для работы с хостингом позволяет автоматизировать управление ресурсами и анализ данных.

## Примеры использования API хостинга:

* Отслеживание состояния аккаунта и своевременный анализ уведомлений
* Автоматическое создание, удаление, конфигурирование ресурсов
* Доступ к данным внутреннего мониторинга 1Gb.ru, анализ качества работы VDS
* Автоматизация типовых реакций на проблемы ресурсов и хостинга 

Доступ к API хостинга активен в любом оплаченном тарифном плане. Для тестовых или бесплатных аккаунтов API не работает. 

## Принципы работы и примеры

Доступ происходит по протоколу HTTPS по базовому адресу https://www.1gb.ru/api/. Параметры большинства запросов можно передавать с помощью GET или POST параметров. Ответ содержит объект или массив объектов по стандарту JSON.

Перед началом работы с API требуется получить token для дальнейшей авторизации. Это делается следующим образом (приведены примеры использования GET параметров):

1. https://www.1gb.ru/api/auth/start?login=[логин_кабинета] - возвращает в ответ string, содержащий соль
2. https://www.1gb.ru/api/auth/login?login=[логин_кабинета]&salt=[соль]&response=[response] - возвращает в ответ string, содержащий token; псевдокод для вычисления response на PHP: *md5($password.$salt.\"\\n\")* (сумма md5 строки \"пароль+соль+символ-перевода-строки\")

Последний запрос возвращает string, в нем token, его нужно запомнить и использовать для последующей авторизации. Token утрачивает силу при смене главного пароля аккаунта, существует также возможность деактивировать отдельные token-ы со страницы кабинета \"смена главного пароля аккаунта\".

Примеры дальнейших запросов:

    https://www.1gb.ru/api/billing/info?_token_=[запомненный token] - получение общих данных аккаунта 

Ответы API с HTTP кодом 200 обозначают успешное исполнение операции. В ответном JSON может содержаться два разных типа:

* [ \"string\" ]: либо просто \"OK\", либо \"[число]\" (необходимо привести к int), если возвращается ID созданного объекта
* [ { ... } , { ... } ] (массив объектов): если запрос возвращает список из 0 или более структур (хеш \"поле\":\"значение\"). 

Другие коды (больше 200) обозначают ошибку, при этом тело ответа содержит string с объяснением, пример: \"ERROR: vds.missing\".

## Команды API и общие соглашения

Большинство команд API, таких как /list, возвращают внутренние структуры из базы данных хостинга, которые содержат сотни полей. Документировать их трудоемко, поэтому рекомендуем просто смотреть на вывод соответствующих команд и анализировать структуры данных по очевидным названиям полей.

В том случае, если трактовка полей вызывает затруднения, пишите на support@1gb.ru, поможем разобраться.

## Общедоступные на данный момент команды

https://www.1gb.ru/api + адрес из списка ниже. Обязательный параметр каждой команды (кроме этапа авторизации) - _token_. Остальные параметры приведены после команды."
  :dependencies [[org.clojure/clojure "1.7.0"]
                 [clj-http "2.0.0"]
                 [cheshire "5.5.0"]])
